summaryrefslogtreecommitdiff
path: root/noncore/settings/networksettings2/nsdata.cpp
Side-by-side diff
Diffstat (limited to 'noncore/settings/networksettings2/nsdata.cpp') (more/less context) (ignore whitespace changes)
-rw-r--r--noncore/settings/networksettings2/nsdata.cpp108
1 files changed, 54 insertions, 54 deletions
diff --git a/noncore/settings/networksettings2/nsdata.cpp b/noncore/settings/networksettings2/nsdata.cpp
index 39031ed..b4622fc 100644
--- a/noncore/settings/networksettings2/nsdata.cpp
+++ b/noncore/settings/networksettings2/nsdata.cpp
@@ -51,5 +51,5 @@ NetworkSettingsData::NetworkSettingsData( void ) {
F->setName( D.path() + "/" + (*it) );
if( F->open( IO_ReadOnly ) ) {
- NodeCollection * NC;
+ NetworkSetup * NC;
interfacename = TS.readLine();
F->close();
@@ -58,5 +58,5 @@ NetworkSettingsData::NetworkSettingsData( void ) {
interfacename.latin1(), profilenr ));
- NC = NSResources->getConnection( profilenr );
+ NC = NSResources->getNetworkSetup( profilenr );
if( NC ) {
NC->assignInterface(
@@ -100,5 +100,5 @@ void NetworkSettingsData::loadSettings( void ) {
Entries ...
<EMPTYLINE>
- [connection]
+ [NetworkSetup]
Name=Name
Node=Name
@@ -117,9 +117,9 @@ void NetworkSettingsData::loadSettings( void ) {
}
- if( S == "connection" ) {
- // load connections -> collections of nodes
+ if( S == "NetworkSetup" ) {
+ // load NetworkSetups -> collections of nodes
bool Dangling;
- NodeCollection * NC = new NodeCollection( TS, Dangling );
- NSResources->addConnection( NC, Dangling );
+ NetworkSetup * NC = new NetworkSetup( TS, Dangling );
+ NSResources->addNetworkSetup( NC, Dangling );
} else {
ANetNode * NN = 0;
@@ -252,24 +252,24 @@ QString NetworkSettingsData::saveSettings( void ) {
}
- // good connections
- { Name2Connection_t & M = NSResources->connections();
+ // good NetworkSetups
+ { Name2NetworkSetup_t & M = NSResources->networkSetups();
- // for all connections
- for( QDictIterator<NodeCollection> it(M);
+ // for all NetworkSetups
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
++it ) {
- TS << "[connection]" << endl;
+ TS << "[NetworkSetup]" << endl;
it.current()->save(TS);
}
}
- // save dangling connections
- { Name2Connection_t & M = NSResources->danglingConnections();
+ // save dangling NetworkSetups
+ { Name2NetworkSetup_t & M = NSResources->danglingNetworkSetups();
- // for all connections
- for( QDictIterator<NodeCollection> it(M);
+ // for all NetworkSetups
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
++it ) {
- TS << "[connection]" << endl;
+ TS << "[NetworkSetup]" << endl;
it.current()->save(TS);
}
@@ -284,5 +284,5 @@ QString NetworkSettingsData::saveSettings( void ) {
- for( QDictIterator<NodeCollection> it(NSResources->connections());
+ for( QDictIterator<NetworkSetup> it(NSResources->networkSetups());
it.current();
++it ) {
@@ -296,6 +296,6 @@ QString NetworkSettingsData::generateSettings( void ) {
QString S = "";
Name2SystemFile_t & SFM = NSResources->systemFiles();
- Name2Connection_t & M = NSResources->connections();
- NodeCollection * NC;
+ Name2NetworkSetup_t & M = NSResources->networkSetups();
+ NetworkSetup * NC;
ANetNodeInstance * NNI;
ANetNodeInstance * FirstWithData;
@@ -429,5 +429,5 @@ QString NetworkSettingsData::generateSettings( void ) {
}
- for( QDictIterator<NodeCollection> ncit(M);
+ for( QDictIterator<NetworkSetup> ncit(M);
ncit.current();
++ncit ) {
@@ -489,6 +489,6 @@ QString NetworkSettingsData::generateSettings( void ) {
}
- // find connections that want to write to this file
- for( QDictIterator<NodeCollection> ncit(M);
+ // find NetworkSetups that want to write to this file
+ for( QDictIterator<NetworkSetup> ncit(M);
ncit.current();
++ncit ) {
@@ -506,10 +506,10 @@ QString NetworkSettingsData::generateSettings( void ) {
}
- Log(("Generating %s for connection %s\n",
+ Log(("Generating %s for NetworkSetup %s\n",
SF->name().latin1(), NC->name().latin1() ));
// find highest item that wants to write data to this file
FirstWithData = NC->firstWithDataForFile( *SF );
// find device on which this connection works
CurDev = NC->device();
// class of that node
@@ -572,6 +572,6 @@ QString NetworkSettingsData::generateSettings( void ) {
// generate profile specific info
- // for all nodeconnections that work on the same device
- for( QDictIterator<NodeCollection> ncit2(M);
+ // for all nodeNetworkSetups that work on the same device
+ for( QDictIterator<NetworkSetup> ncit2(M);
ncit2.current();
++ncit2 ) {
@@ -582,5 +582,5 @@ QString NetworkSettingsData::generateSettings( void ) {
}
- Log(("Connection %s of family %s\n",
+ Log(("NetworkSetup %s of family %s\n",
ncit2.current()->name().latin1(),
CurDev->name() ));
@@ -646,13 +646,13 @@ QString NetworkSettingsData::generateSettings( void ) {
}
-QList<NodeCollection> NetworkSettingsData::collectPossible(
+QList<NetworkSetup> NetworkSettingsData::collectPossible(
const QString & Interface ) {
- // collect connections that can work on top of this interface
- NodeCollection * NC;
- QList<NodeCollection> PossibleConnections;
- Name2Connection_t & M = NSResources->connections();
+ // collect NetworkSetups that can work on top of this interface
+ NetworkSetup * NC;
+ QList<NetworkSetup> PossibleNetworkSetups;
+ Name2NetworkSetup_t & M = NSResources->networkSetups();
- // for all connections
- for( QDictIterator<NodeCollection> it(M);
+ // for all NetworkSetups
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
++it ) {
@@ -665,8 +665,8 @@ QList<NodeCollection> NetworkSettingsData::collectPossible(
Log( ( "Append %s for %s\n",
NC->name().latin1(), Interface.latin1() ));
- PossibleConnections.append( NC );
+ PossibleNetworkSetups.append( NC );
}
}
- return PossibleConnections;
+ return PossibleNetworkSetups;
}
@@ -680,16 +680,16 @@ QList<NodeCollection> NetworkSettingsData::collectPossible(
bool NetworkSettingsData::canStart( const QString & Interface ) {
// load situation
- NodeCollection * NC = 0;
- QList<NodeCollection> PossibleConnections;
+ NetworkSetup * NC = 0;
+ QList<NetworkSetup> PossibleNetworkSetups;
- PossibleConnections = collectPossible( Interface );
+ PossibleNetworkSetups = collectPossible( Interface );
Log( ( "for %s : Possiblilies %d\n",
- Interface.latin1(), PossibleConnections.count() ));
- switch( PossibleConnections.count() ) {
- case 0 : // no connections
+ Interface.latin1(), PossibleNetworkSetups.count() ));
+ switch( PossibleNetworkSetups.count() ) {
+ case 0 : // no NetworkSetups
break;
- case 1 : // one connection
- NC = PossibleConnections.first();
+ case 1 : // one NetworkSetup
+ NC = PossibleNetworkSetups.first();
break;
default : // need to ask user ?
@@ -737,5 +737,5 @@ bool NetworkSettingsData::isModified( void ) {
return 1;
- for( QDictIterator<NodeCollection> it(NSResources->connections());
+ for( QDictIterator<NetworkSetup> it(NSResources->networkSetups());
it.current();
++it ) {
@@ -749,5 +749,5 @@ bool NetworkSettingsData::isModified( void ) {
bool NetworkSettingsData::couldBeTriggered( const QString & Interface ) {
// load situation
- QList<NodeCollection> PossibleTriggered;
+ QList<NetworkSetup> PossibleTriggered;
PossibleTriggered = collectTriggered( Interface );
@@ -759,15 +759,15 @@ bool NetworkSettingsData::couldBeTriggered( const QString & Interface ) {
}
-QList<NodeCollection> NetworkSettingsData::collectTriggered(
+QList<NetworkSetup> NetworkSettingsData::collectTriggered(
const QString & Interface ) {
- // collect connections that could be triggered by this interface
- NodeCollection * NC;
- QList<NodeCollection> PossibleTriggered;
+ // collect NetworkSetups that could be triggered by this interface
+ NetworkSetup * NC;
+ QList<NetworkSetup> PossibleTriggered;
- // for all connections
- Name2Connection_t & M = NSResources->connections();
+ // for all NetworkSetups
+ Name2NetworkSetup_t & M = NSResources->networkSetups();
- for( QDictIterator<NodeCollection> it(M);
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
++it ) {
@@ -506,10 +506,10 @@ QString NetworkSettingsData::generateSettings( void ) {
// find highest item that wants to write data to this file
FirstWithData = NC->firstWithDataForFile( *SF );
- // find device on which this connection works
+ // find device on which this NetworkSetup works
CurDev = NC->device();
// class of that node